@@ -1,6 +1,5 @@
-if (!covr::in_covr()) {
-  skip_on_cran()
-}
+
+skip_on_cran()
 
 test_that("it should download cdi/idi file", {
   f <- download_marketdata("CDIIDI")
@@ -26,4 +25,4 @@ test_that("it should get idi index", {
   df <- idi_get()
   expect_s3_class(df$refdate, "Date")
   expect_true(is(df$IDI, "numeric"))
-})
\ No newline at end of file
+})
